@@ -1,12 +1,17 @@
 # frozen_string_literal: true
-require('bootsnap/bootsnap')
-require('zlib')
+
+require("bootsnap/bootsnap")
+require("zlib")
 
 module Bootsnap
   module CompileCache
     module ISeq
       class << self
-        attr_accessor(:cache_dir)
+        attr_reader(:cache_dir)
+
+        def cache_dir=(cache_dir)
+          @cache_dir = cache_dir.end_with?("/") ? "#{cache_dir}iseq" : "#{cache_dir}-iseq"
+        end
       end
 
       has_ruby_bug_18250 = begin # https://bugs.ruby-lang.org/issues/18250
@@ -23,28 +28,28 @@ module Bootsnap
           iseq = begin
             RubyVM::InstructionSequence.compile_file(path)
           rescue SyntaxError
-            raise(Uncompilable, 'syntax error')
+            return UNCOMPILABLE # syntax error
           end
 
           begin
             iseq.to_binary
           rescue TypeError
-            raise(Uncompilable, 'ruby bug #18250')
+            UNCOMPILABLE # ruby bug #18250
           end
         end
       else
         def self.input_to_storage(_, path)
           RubyVM::InstructionSequence.compile_file(path).to_binary
         rescue SyntaxError
-          raise(Uncompilable, 'syntax error')
+          UNCOMPILABLE # syntax error
         end
       end
 
       def self.storage_to_output(binary, _args)
         RubyVM::InstructionSequence.load_from_binary(binary)
-      rescue RuntimeError => e
-        if e.message == 'broken binary format'
-          STDERR.puts("[Bootsnap::CompileCache] warning: rejecting broken binary")
+      rescue RuntimeError => error
+        if error.message == "broken binary format"
+          $stderr.puts("[Bootsnap::CompileCache] warning: rejecting broken binary")
           nil
         else
           raise
@@ -60,7 +65,7 @@ module Bootsnap
         )
       end
 
-      def self.precompile(path, cache_dir: ISeq.cache_dir)
+      def self.precompile(path)
         Bootsnap::CompileCache::Native.precompile(
           cache_dir,
           path.to_s,
@@ -80,8 +85,8 @@ module Bootsnap
           Bootsnap::CompileCache::ISeq.fetch(path.to_s)
         rescue Errno::EACCES
           Bootsnap::CompileCache.permission_error(path)
-        rescue RuntimeError => e
-          if e.message =~ /unmatched platform/
+        rescue RuntimeError => error
+          if error.message =~ /unmatched platform/
             puts("unmatched platform for file #{path}")
           end
           raise
