@@ -6,6 +6,8 @@ module Kernel
   alias_method(:require_without_bootsnap, :require)
 
   def require(path)
+    return require_without_bootsnap(path) unless Bootsnap::LoadPathCache.enabled?
+
     string_path = Bootsnap.rb_get_path(path)
     return false if Bootsnap::LoadPathCache.loaded_features_index.key?(string_path)
 
@@ -32,13 +34,4 @@ module Kernel
       return ret
     end
   end
-
-  alias_method(:load_without_bootsnap, :load)
-  def load(path, wrap = false)
-    if (resolved = Bootsnap::LoadPathCache.load_path_cache.find(Bootsnap.rb_get_path(path), try_extensions: false))
-      load_without_bootsnap(resolved, wrap)
-    else
-      load_without_bootsnap(path, wrap)
-    end
-  end
 end
