@@ -29,14 +29,15 @@ module Bootsnap
         @mutex = Mutex.new
 
         # In theory the user could mutate $LOADED_FEATURES and invalidate our
-        # cache. If this ever comes up in practice — or if you, the
-        # enterprising reader, feels inclined to solve this problem — we could
+        # cache. If this ever comes up in practice - or if you, the
+        # enterprising reader, feels inclined to solve this problem - we could
         # parallel the work done with ChangeObserver on $LOAD_PATH to mirror
         # updates to our @lfi.
         $LOADED_FEATURES.each do |feat|
           hash = feat.hash
           $LOAD_PATH.each do |lpe|
             next unless feat.start_with?(lpe)
+
             # /a/b/lib/my/foo.rb
             #          ^^^^^^^^^
             short = feat[(lpe.length + 1)..-1]
@@ -68,11 +69,30 @@ module Bootsnap
         @mutex.synchronize { @lfi.key?(feature) }
       end
 
+      def cursor(short)
+        unless Bootsnap.absolute_path?(short.to_s)
+          $LOADED_FEATURES.size
+        end
+      end
+
+      def identify(short, cursor)
+        $LOADED_FEATURES[cursor..-1].detect do |feat|
+          offset = 0
+          while (offset = feat.index(short, offset))
+            if feat.index(".", offset + 1) && !feat.index("/", offset + 2)
+              break true
+            else
+              offset += 1
+            end
+          end
+        end
+      end
+
       # There is a relatively uncommon case where we could miss adding an
       # entry:
       #
       # If the user asked for e.g. `require 'bundler'`, and we went through the
-      # `FallbackScan` pathway in `kernel_require.rb` and therefore did not
+      # `FALLBACK_SCAN` pathway in `kernel_require.rb` and therefore did not
       # pass `long` (the full expanded absolute path), then we did are not able
       # to confidently add the `bundler.rb` form to @lfi.
       #
@@ -82,23 +102,8 @@ module Bootsnap
       #    not quite right; or
       # 2. Inspect $LOADED_FEATURES upon return from yield to find the matching
       #    entry.
-      def register(short, long = nil)
-        if long.nil?
-          len = $LOADED_FEATURES.size
-          ret = yield
-          long = $LOADED_FEATURES[len..-1].detect do |feat|
-            offset = 0
-            while offset = feat.index(short, offset)
-              if feat.index(".", offset + 1) && !feat.index("/", offset + 2)
-                break true
-              else
-                offset += 1
-              end
-            end
-          end
-        else
-          ret = yield
-        end
+      def register(short, long)
+        return if Bootsnap.absolute_path?(short)
 
         hash = long.hash
 
@@ -117,13 +122,11 @@ module Bootsnap
           @lfi[short] = hash
           (@lfi[altname] = hash) if altname
         end
-
-        ret
       end
 
       private
 
-      STRIP_EXTENSION = /\.[^.]*?$/
+      STRIP_EXTENSION = /\.[^.]*?$/.freeze
       private_constant(:STRIP_EXTENSION)
 
       # Might Ruby automatically search for this extension if
@@ -140,15 +143,15 @@ module Bootsnap
       # with calling a Ruby file 'x.dylib.rb' and then requiring it as 'x.dylib'.)
       #
       # See <https://ruby-doc.org/core-2.6.4/Kernel.html#method-i-require>.
-      def extension_elidable?(f)
-        f.to_s.end_with?('.rb', '.so', '.o', '.dll', '.dylib')
+      def extension_elidable?(feature)
+        feature.to_s.end_with?(".rb", ".so", ".o", ".dll", ".dylib")
       end
 
-      def strip_extension_if_elidable(f)
-        if extension_elidable?(f)
-          f.sub(STRIP_EXTENSION, '')
+      def strip_extension_if_elidable(feature)
+        if extension_elidable?(feature)
+          feature.sub(STRIP_EXTENSION, "")
         else
-          f
+          feature
         end
       end
     end
