@@ -1,5 +1,6 @@
 # frozen_string_literal: true
-require_relative('path_scanner')
+
+require_relative("path_scanner")
 
 module Bootsnap
   module LoadPathCache
@@ -20,14 +21,32 @@ module Bootsnap
 
       attr_reader(:path)
 
-      def initialize(path)
+      def initialize(path, real: false)
         @path = path.to_s.freeze
+        @real = real
+      end
+
+      def to_realpath
+        return self if @real
+
+        realpath = begin
+          File.realpath(path)
+        rescue Errno::ENOENT
+          return self
+        end
+
+        if realpath == path
+          @real = true
+          self
+        else
+          Path.new(realpath, real: true)
+        end
       end
 
       # True if the path exists, but represents a non-directory object
       def non_directory?
         !File.stat(path).directory?
-      rescue Errno::ENOENT, Errno::ENOTDIR
+      rescue Errno::ENOENT, Errno::ENOTDIR, Errno::EINVAL
         false
       end
 
@@ -43,6 +62,7 @@ module Bootsnap
           # set to zero anyway, just in case we change the stability heuristics.
           _, entries, dirs = store.get(expanded_path)
           return [entries, dirs] if entries # cache hit
+
           entries, dirs = scan!
           store.set(expanded_path, [0, entries, dirs])
           return [entries, dirs]
@@ -60,7 +80,11 @@ module Bootsnap
       end
 
       def expanded_path
-        File.expand_path(path).freeze
+        if @real
+          path
+        else
+          @expanded_path ||= File.expand_path(path).freeze
+        end
       end
 
       private
@@ -77,7 +101,7 @@ module Bootsnap
         ["", *dirs].each do |dir|
           curr = begin
             File.mtime("#{path}/#{dir}").to_i
-                 rescue Errno::ENOENT, Errno::ENOTDIR
+                 rescue Errno::ENOENT, Errno::ENOTDIR, Errno::EINVAL
                    -1
           end
           max = curr if curr > max
@@ -93,20 +117,18 @@ module Bootsnap
 
       # Built-in ruby lib stuff doesn't change, but things can occasionally be
       # installed into sitedir, which generally lives under libdir.
-      RUBY_LIBDIR  = RbConfig::CONFIG['libdir']
-      RUBY_SITEDIR = RbConfig::CONFIG['sitedir']
+      RUBY_LIBDIR  = RbConfig::CONFIG["libdir"]
+      RUBY_SITEDIR = RbConfig::CONFIG["sitedir"]
 
       def stability
-        @stability ||= begin
-          if Gem.path.detect { |p| expanded_path.start_with?(p.to_s) }
-            STABLE
-          elsif Bootsnap.bundler? && expanded_path.start_with?(Bundler.bundle_path.to_s)
-            STABLE
-          elsif expanded_path.start_with?(RUBY_LIBDIR) && !expanded_path.start_with?(RUBY_SITEDIR)
-            STABLE
-          else
-            VOLATILE
-          end
+        @stability ||= if Gem.path.detect { |p| expanded_path.start_with?(p.to_s) }
+          STABLE
+        elsif Bootsnap.bundler? && expanded_path.start_with?(Bundler.bundle_path.to_s)
+          STABLE
+        elsif expanded_path.start_with?(RUBY_LIBDIR) && !expanded_path.start_with?(RUBY_SITEDIR)
+          STABLE
+        else
+          VOLATILE
         end
       end
     end
