@@ -1,4 +1,5 @@
 # frozen_string_literal: true
-require_relative('../bootsnap')
+
+require_relative("../bootsnap")
 
 Bootsnap.default_setup
