@@ -1,6 +1,7 @@
 # frozen_string_literal: true
-require('test_helper')
-require('bootsnap/load_path_cache')
+
+require("test_helper")
+require("bootsnap/load_path_cache")
 
 module Bootsnap
   module LoadPathCache
@@ -10,17 +11,17 @@ module Bootsnap
       end
 
       def test_stability
-        require('time')
+        require("time")
         time_file       = Time.method(:rfc2822).source_location[0]
         volatile        = Path.new(__FILE__)
         stable          = Path.new(time_file)
-        unknown         = Path.new('/who/knows')
-        lib             = Path.new(RbConfig::CONFIG['libdir']  + '/a')
-        site            = Path.new(RbConfig::CONFIG['sitedir'] + '/b')
-        absolute_prefix = RbConfig::CONFIG['host_os'] =~ /mswin|mingw|cygwin/ ? ENV['SystemDrive'] : ''
-        bundler         = Path.new(absolute_prefix + '/bp/3')
+        unknown         = Path.new("/who/knows")
+        lib             = Path.new("#{RbConfig::CONFIG['libdir']}/a")
+        site            = Path.new("#{RbConfig::CONFIG['sitedir']}/b")
+        absolute_prefix = RbConfig::CONFIG["host_os"] =~ /mswin|mingw|cygwin/ ? ENV["SystemDrive"] : ""
+        bundler         = Path.new("#{absolute_prefix}/bp/3")
 
-        Bundler.stubs(:bundle_path).returns(absolute_prefix + '/bp')
+        Bundler.stubs(:bundle_path).returns("#{absolute_prefix}/bp")
 
         assert(stable.stable?, "The stable path #{stable.path.inspect} was unexpectedly not stable.")
         refute(stable.volatile?, "The stable path #{stable.path.inspect} was unexpectedly volatile.")
@@ -35,17 +36,17 @@ module Bootsnap
       end
 
       def test_non_directory?
-        if RbConfig::CONFIG['host_os'] =~ /mswin|mingw|cygwin/
-          refute(Path.new('c:/dev').non_directory?)
-          refute(Path.new('c:/nope').non_directory?)
+        if RbConfig::CONFIG["host_os"] =~ /mswin|mingw|cygwin/
+          refute(Path.new("c:/dev").non_directory?)
+          refute(Path.new("c:/nope").non_directory?)
           # there isn't a direct analog i could think of
           # assert(Path.new('/dev/null').non_directory?)
           assert(Path.new("#{ENV['WinDir']}/System32/Drivers/Etc/hosts").non_directory?)
         else
-          refute(Path.new('/dev').non_directory?)
-          refute(Path.new('/nope').non_directory?)
-          assert(Path.new('/dev/null').non_directory?)
-          assert(Path.new('/etc/hosts').non_directory?)
+          refute(Path.new("/dev").non_directory?)
+          refute(Path.new("/nope").non_directory?)
+          assert(Path.new("/dev/null").non_directory?)
+          assert(Path.new("/etc/hosts").non_directory?)
         end
       end
 
@@ -54,7 +55,7 @@ module Bootsnap
           entries, dirs = PathScanner.call(dir)
           path = Path.new(dir) # volatile, since it'll be in /tmp
 
-          @cache.expects(:get).with(dir).returns([100, entries, dirs])
+          @cache.expects(:get).with(path.expanded_path).returns([100, entries, dirs])
 
           path.entries_and_dirs(@cache)
         end
@@ -67,11 +68,11 @@ module Bootsnap
 
           FileUtils.touch(a_b, mtime: Time.at(101))
 
-          @cache.expects(:get).with(dir).returns([100, entries, dirs])
-          @cache.expects(:set).with(dir, [101, entries, dirs])
+          @cache.expects(:get).with(path.expanded_path).returns([100, entries, dirs])
+          @cache.expects(:set).with(path.expanded_path, [101, entries, dirs])
 
           # next read doesn't regen
-          @cache.expects(:get).with(dir).returns([101, entries, dirs])
+          @cache.expects(:get).with(path.expanded_path).returns([101, entries, dirs])
 
           path.entries_and_dirs(@cache)
           path.entries_and_dirs(@cache)
@@ -83,8 +84,8 @@ module Bootsnap
           entries, dirs = PathScanner.call(dir)
           path = Path.new(dir) # volatile, since it'll be in /tmp
 
-          @cache.expects(:get).with(dir).returns(nil)
-          @cache.expects(:set).with(dir, [100, entries, dirs])
+          @cache.expects(:get).with(path.expanded_path).returns(nil)
+          @cache.expects(:set).with(path.expanded_path, [100, entries, dirs])
 
           path.entries_and_dirs(@cache)
         end
@@ -100,7 +101,7 @@ module Bootsnap
 
           # It's unfortunate that we're stubbing the impl of #fetch here.
           PathScanner.expects(:call).never
-          @cache.expects(:get).with(dir).returns([100, entries, dirs])
+          @cache.expects(:get).with(path.expanded_path).returns([100, entries, dirs])
 
           path.entries_and_dirs(@cache)
         end
